**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name              modelEco_ParisBasin_regulation.gms
Sequence         2 - The farm model
GAMS language    subassembly/subset, alias
Type             LP
Description
"A farmer in the Paris basin has a 100 ha arable crop farm.
He can grow soft wheat (Wheat), rapeseed, spring barley (SBarley) and winter barley (WBarley) and hemp (Hemp) in Integrated pest management only. For each crop, he can choose between three management systems :

Intensive (written  Intens ) : it is the most intensive system in terms of chemical inputs.
The farmer often has a preventive use of phytosanitary products. In other words, he does not wait for the appearance of diseases or pests in order to spray the crops.
Sustainable (written  Sust ) : it involves sustainable practices. . The interventions of the farmer are determined following the observation of diseases or pests in the plot.
The quantities used are adapted to the situation.
Integrated pest management ( written  IPM ) : such practices integrate prophylactic agronomic measures which contribute to a decrease in the pressure caused by pests.
They can involve considerations concerning sowing dates, variety choices, crop successions in a plot, etc
Integrated pest management at cropping system level (written  SystIPM ) :
this practice was developed in order to fight against pests and offers agronomic levers at cropping system level, notably with a change in crop patterns.
The details of the variable costs are known for each management system and each crop :
phytosanitary products (Phyto_C), fertilizer (Fert_C), seeds (Seeds_C) and mechanization (Mech_C) (fuel and depreciation) expenses.
The farmer knows the expected yields and labour needs for each management system and each crop.
The farmer can work 2000 hours a year.
The selling prices of the different crop types are as follows : 180/t for soft wheat, 365/t for rapeseed, 170/t for spring barley, 155/t for winter barley and 320/t for hemp.

It was observed that farmers used a crop pattern for organisational reasons,
by alternating summer crops and winter crops, and for agronomic reasons notably due to the positive effects of a crop on the next one : soil structure and fertility, pest control, etc.
But rotations are currently often short (one crop can sometimes be used twice in a row), which leads to the need to increase the inputs in fertilizer and phytosanitary products."
In the  intensive    sustainable  and  integrated pest management  management systems, the rotation must respect the following agronomic rules :
 Oilseed crops cannot be cultivated more than once every three years on the same plot,
 cereal crops cannot be grown two years in a row
 each cereal crop can be cultivated on half the cultivated area dedicated to cereal crops at the most
The final rotation, that of  integrated cropping system  introduces hemp in order to extend the rotation.
Longer rotations, which imply that a crop is grown less frequently in the rotation, make it possible to control pests more efficiently. It follows the following rules :
 oilseed crops cannot be cultivated more than once every three years on the same plot,
 cereal crops cannot be grown more than one year on the same plot
 each cereal crop can be cultivated on half the cultivated area dedicated to cereal crops at the most
 hemp is grown once every six years

An indicator is used in order to calculate the use of phytosanitary products per crop, the Treatment Frequency Index (TFI) per hectare,
which combines the number of of spray applications and the doses applied: the more intensive the management system, the higher the index (see table below).
Hemp is not treated chemically. Its TFI is therefore always equal to 0. Phytosanitary products are divided into four categories :
herbicide (herb), fungicide (fung), insecticide (ins), other.
The objective of the farmer is to maximize his income.

The data come from : Ecophyto R&D vers des systmes de culture conomes en produits phytosanitaires   Volet 1.
 Tome II : Analyse comparative de diffrents systmes en grandes cultures.
Janvier 2009. INRA et le ministre de lcologie, de lnergie, du dveloppement durable et de lamnagement du territoire.

$offtext

*-----------------------------------------------------------------------------*


*----------                          DECLARATIONS                   ----------*
SET

C          crops                     /Wheat, Rapeseed, SBarley, Hemp, WBarley/
typeC                                /cere, olea, Hemp/
Cere(C)    Cereal crops              /Wheat,SBarley,WBarley/
Olea(C)    Oilseed crops             /Rapeseed/
MS         management systems        /Intens, Sust, IPM, SystIPM/
Phyt       phytosanitary products    /herb, fung, ins, other/
Va_Costs   variable costs            /Phyto_C, Fert_C, Seeds_C, Mech_C/

sc         scenarios                 /sc1, sc2, sc3, sc4/;

alias(cere, cereC);

scalar
Land_A     land availability             /100/
Labour_A   labour availability in hours  /2000/
TFILim     TFI limite
;

parameter
SellingPrice(C)     selling price per crop
/Wheat 180, Rapeseed 365, SBarley 170, WBarley 155, Hemp 320/
;

table
CostTFI(C,Phyt)    cost of purchasing TFIs per crop and per type of phytosanitary product
             herb     fung     ins      other
Wheat        35        35        8        9
Rapeseed     43        41       11       15
SBarley      35        90       10       12
WBarley      35        90       10       12
Hemp         50        35       10       10
;

table
T_Costs          total costs per crop and per management system
                              Intens      Sust     IPM      SystIPM
Wheat.        Phyto_C          142        112        73        59
Wheat.        Fert_C           192        187       168       168
Wheat.        Seeds_C           50         50        30        30
Wheat.        Mech_C           268        262       263       263
Rapeseed.     Phyto_C          203        153       101        57
Rapeseed.     Fert_C           170        157       139       131
Rapeseed.     Seeds_C           37         37        37        37
Rapeseed.     Mech_C           314        288       299       304
SBarley.      Phyto_C          192        201       120       103
SBarley.      Fert_C           149        147       133       133
SBarley.      Seeds_C           65         65        65        65
SBarley.      Mech_C           262        263       276       287
WBarley.      Phyto_C          234        192       117       110
WBarley.      Fert_C           166        164       147       147
WBarley.      Seeds_C           65         65        65        65
WBarley.      Mech_C           278        259       258       265
Hemp.         Phyto_C            0          0         0         0
Hemp.         Fert_C             0          0         0       162
Hemp.         Seeds_C            0          0         0        90
Hemp.         Mech_C             0          0         0       124

;
table
utTFI(C, Phyt, MS)    use of TFIs per crop and per type of phytosanitary product and per management system
                         Intens     Sust       IPM      SystIPM
Wheat.        herb        1.6       1.6        1.2        1
Wheat.        fung        2.1       1.3        0.8        0.6
Wheat.        ins         0.6       0.5        0.2        0.2
Wheat.        other       0.9       0.7        0.2        0.2
Rapeseed.     herb        2.2       1.5        1          0.75
Rapeseed.     fung        1.3       1.2        0.8        0
Rapeseed.     ins         4.2       2.7        2          2
Rapeseed.     other       0.6       0.6        0.2        0.2
SBarley.      herb        1.6       1.6        1.3        0.8
SBarley.      fung        1.4       1.5        0.75       0.75
SBarley.      ins         0.2       0.15       0.1        0.1
SBarley.      other       0.7       0.7        0.5        0.5
WBarley.      herb        1.9       1.5        1.2        1
WBarley.      fung        1.7       1.5        0.8        0.8
WBarley.      ins         0.5       0.1        0.1        0.1
WBarley.      other       0.8       0.3        0.2        0.2
Hemp.         herb        0         0          0          0
Hemp.         fung        0         0          0          0
Hemp.         ins         0         0          0          0
Hemp.         other       0         0          0          0
;

parameter
TFI_c(C, MS)          Total TFI calculation;
TFI_c(C, MS) = sum(Phyt, utTFI(C, Phyt, MS)) ;

table
Yields(C, MS)      Yields per crop and per management systems in quintals per HA
         Intens    Sust     IPM   SystIPM
Wheat     72.8      71       65      66
Rapeseed  31        29       26.3    26
SBarley   62.6      62       56      57
WBarley   71        70       64      65
Hemp       0         0        0      10.5

;

table
LabourNeeds        labour needs per crop and management system
          Intens    Sust      IPM    SystIPM
Wheat       3.2      3.1      3.1      3.1
Rapeseed    4        3.6      4        4.1
SBarley     3.1      3.1      3.3      3.4
WBarley     3.3      3        3        3.1
Hemp        0        1.8      1.8      1.8
;

table
prop2(typeC,MS)   proportion out of 3
       Intens    Sust     IPM   SystIPM
cere      4        4        4        3
olea      2        2        2        2
Hemp      0        0        0        1
;
scalar idprop2    /6/;


parameter
GM(C, MS)       calculated gross margin
;
GM(C, MS) = Yields(C,MS)*SellingPrice(C)/10 - sum(Va_Costs, T_Costs(C, Va_Costs, MS))
;

display SellingPrice, CostTFI, T_Costs, Yields, LabourNeeds, utTFI ;
display GM, TFI_c
;

variables
Z
X
TFIha
;

positive variables
X
;

equations
objective
land
labour
TFI
TFIMax

rotCere(MS)
rotOlea(MS)
rotCere2(MS,cere)
rotChan
;

objective..         sum[(C, MS), X(C, MS)* GM(C, MS)] =e= Z;
land..              sum[(C, MS), X(C,MS)] =l= Land_A ;
labour..            sum[(C, MS), X(C, MS)*LabourNeeds(C, MS)] =l= Labour_A ;
TFI..               sum[(C, MS), X(C, MS)*TFI_c(C, MS)] =e= TFIha   ;
TFIMax..            TFIha =l= TFILim *{sum[(C,MS), X(C,MS)]};

rotCere(MS)..       sum(cere,X(cere,MS))=l=sum(C,X(C,MS))*prop2('cere',MS)/idprop2;
rotOlea(MS)..       sum(olea,X(olea,MS))=l=sum(C,X(C,MS))*prop2('olea',MS)/idprop2;
rotCere2(MS,cere).. X(cere, MS) =l= 0.5*sum(cereC, X(cereC,MS));
rotChan..           X('Hemp', 'SystIPM') =e= sum(C,X(C,'SystIPM'))*prop2('Hemp','SystIPM')/idprop2;

model farmModel "basic farm model"  /all/;

parameter
TFILim_sc(sc)
/
sc1 5
sc2 4
sc3 3
sc4 2.5
/
;

parameter RESULT ;

LOOP(sc,
TFILim = TFILim_sc(sc) ;

solve farmModel using NLP maximizing Z ;

RESULT(C, MS, sc) = X.L(C, MS) ;
RESULT('income', '', sc) = Z.L ;
RESULT('TFILim','',sc) = TFILim ;
RESULT('TFITot','',sc) = TFIha.L /{sum[(C,MS), X.l(C,MS)]} ;
RESULT('statut','model',sc)=farmModel.modelStat ;
RESULT('statut','solver',sc)=farmModel.solveStat ;
)
;

display RESULT ;


